#!/bin/sh
#
# This script will test min/max tilt position on actuator.
# This test actually checks that modem and RS485 ports are working
#  properly.  min/max will allow enough data to be passed between the
#  actuator and the ACU.
#
# Prerequisites:
#  Database should be prebuilt for all aisg devices in the test fixture
#   before running this script.
#
#  Serial number for atc300 will be collected in the install script and
#   main script file will just ask for the operator info.
#
#  Hardware clock for atc300 will be set in the install script also.
#
#  Tilt positions will be predefined.
#

TEST=$1
DEVS=$2
RUNS=$3

#
# 3 test for different tilt positions
#
# 08-20-07
# Added check for .1 degree tolerance, no negative number.
#
LIST=""
if [ "$TEST" = "1" ]; then
	LIST="0.0 2.0"
	LISTHL="0.1 2.1"
	LISTLL="0.0 1.9"
fi
if [ "$TEST" = "2" ]; then
	LIST="2.0 0.0"
	LISTHL="2.1 0.1"
	LISTLL="1.9 0.0"
fi
if [ "$TEST" = "3" ]; then
	LIST="0 2.3 4.6 7 4.6 2.3"
	LISTHL="0.1 2.4 4.7 7.1 4.7 2.4"
	LISTLL="0 2.2 4.5 6.9 4.5 2.2"
fi
if [ "$TEST" = "4" ]; then
	LIST="2 4 6 8"
	LISTHL="2.1 4.1 6.1 8.1"
	LISTLL="1.9 3.9 5.9 7.9"
fi

################################################################################
# Give Usage Information
################################################################################
usage()
{
    echo "Usage: $0 {Test_Number Device_Number Run_Count}"
    echo "  All arguments must be provided"
    echo "  Test_Number   - 1 thru 4"
    echo "  Device_Number - 0 thru 7, 0 = all device"
    echo "  Run_Count     - 0 = Continuous"
    exit 1
}

################################################################################
# Give Usage Information
################################################################################
set_time()
{
    echo "$0: Setting system time from HW clock."
    hwclock -s
}

################################################################################
# Retrieve all device numbers from database if not provided.
################################################################################
get_device_count()
{
    if [ "$DEVS" = 0 ];then
    	DEVS=`cut -f 1 /var/ascu/Device.db`
	    echo "devs = $DEVS" >> /var/log/atc300_tilt.log

        if [ "$DEVS" = 0 ];then
            echo "No devices found in database."
            exit 1
        fi
    fi
}

################################################################################
# Retrieve Hardware & Software Info for each device in the database.
# i.e.
# "1,Get Hardware & Software Info,ATM3,0000DESA064700153,01.00,1.2.65"
################################################################################
get_device_info()
{
    echo "ATC300 Serial Number: `cat /Serial.txt`" >> /var/log/atc300_tilt.log

    timestamp=`date | sed "s/UTC //"`
    echo "$timestamp,Test Started" >> /var/log/atc300_tilt.log
    echo "Address,Command,Product,Serial,HWVersion,SWVersion" >> /var/log/atc300_tilt.log
    for name in $DEVS ; do
    	export QUERY_STRING="name=$name&command=5"
	echo "$QUERY_STRING" >> /var/log/atc300_tilt.log
    	/usr/bin/aisg_command -s , >> /var/log/atc300_tilt.log
    done
}

################################################################################
# Move aisg to min and max position.
################################################################################
run_tilt_test()
{
    echo "Timestamp,Tilt,Address,Response" >> /var/log/atc300_tilt.log

    # run counter
#    RUNCNT=0
#    if [ $RUNS = 0 ]; then
#        RUNCNT=1
#    else
#        RUNCNT=$RUNS
#    fi

#    while [ $RUNCNT -ge 1 ]; do
        index=1
       	for tilt in $LIST ; do
            # get high and low tolerance limit.
            listhl=`echo $LISTHL |cut -d ' ' -f $index`
            listll=`echo $LISTLL |cut -d ' ' -f $index`

       	   	for name in $DEVS ; do
    			# Set Tilt
    			export QUERY_STRING="tilt=$tilt&name=$name&command=51"
   	            echo "$QUERY_STRING" >> /var/log/atc300_tilt.log
       	   		timestamp=`date | sed "s/UTC //"`
    	   		echo -n $timestamp, >> /var/log/atc300_tilt.log
    	   		echo -n $tilt, >> /var/log/atc300_tilt.log
       			TILT_STATUS_MSG=`/usr/bin/aisg_command -s ,`

                #
                # check return status for errors.
                #  example: "1,RET Set Tilt,OK"
                #
                echo "$TILT_STATUS_MSG" >> /var/log/atc300_tilt.log
                TILT_STATUS=`echo "$TILT_STATUS_MSG" | cut -d ',' -f 3`
                echo $TILT_STATUS_MSG
                #
                # 05-03-07
                # Tile move to current position will now return the
                #  "Get Tilt" info not "Set Tilt"
#                if [ "$TILT_STATUS" != "OK" ]; then
                #
                # 08-20-07
                # Added check for .1 degree tolerance, no negative number.
#                if [ "$TILT_STATUS" != "OK" -a "$TILT_STATUS" != "$tilt" ]; then
                #
                if [ "$TILT_STATUS" != "OK" -a "$TILT_STATUS" != "$tilt" -a "$TILT_STATUS" != "$listhl" -a "$TILT_STATUS" != "$listll" ]; then
                    echo "Tilt test failed."
                    echo "$TILT_STATUS_MSG"
                    exit 1
                else
           	   		export QUERY_STRING="action=Get+Queue+Depth"
           	   		QD=1
           	   		while [ $QD != 0 ]; do
           	   			QD=`aisg_command | cut -f 4`
           	   			sleep 1
           	   		done

                    #
           	   		# Get tilt status
                    #
           	   		export QUERY_STRING="tilt=$tilt&name=$name&command=52"
                   	echo "$QUERY_STRING" >> /var/log/atc300_tilt.log
           	   		timestamp=`date | sed "s/UTC //"`
        	   		echo -n $timestamp, >> /var/log/atc300_tilt.log
        	   		echo -n $tilt, >> /var/log/atc300_tilt.log
           	   		TILT_STATUS_MSG=`/usr/bin/aisg_command -s ,`

                    #
                    # check return status for errors.
                    # The returned status is different from what is
                    #  specified in the AISG 1.1 standard.
                    # No "OK" or "FAIL" is returned in the status.
                    #  example: "1,RET Get Tilt,0.0"
                    #
                    echo "$TILT_STATUS_MSG" >> /var/log/atc300_tilt.log
                    echo "$TILT_STATUS_MSG"
                    TILT_STATUS=`echo "$TILT_STATUS_MSG" | cut -d ',' -f 3`
                    #
                    # 08-20-07
                    # Added check for .1 degree tolerance, no negative number.
#                    if [ "$TILT_STATUS" != "$tilt" ]; then
                    #
                    if [ "$TILT_STATUS" != "$tilt" -a "$TILT_STATUS" != "$listhl" -a "$TILT_STATUS" != "$listll" ]; then
                        echo "Tilt test failed."
                        echo "$TILT_STATUS_MSG"
                        exit 1
                    fi
                fi

       	   	done

            let "index += 1"
       	done
        # decrement run counter when not continuous
#        if [ $RUNS > 0 ]; then
#            RUNCNT=$RUNCNT-1
#        fi
#   	done

    timestamp=`date | sed "s/UTC //"`
    echo "$timestamp,Tilt Test Completed" >> /var/log/atc300_tilt.log
    echo "Tilt Test Completed"
}

################################################################################
# Stop all running ascu applications and manually delete device database
#  and backup database files.  We can not use the "delall.sh" script
#  because this script actually disables the actuators.
# This is to support factory reinstallation of software.
################################################################################
kill_clean()
{
    # stop ascu
    killall alarm_mgr_wrapper.sh >/dev/null 2>&1
    killall thttpd_wrapper >/dev/null 2>&1
    killall snmpd_wrapper.sh >/dev/null 2>&1
    killall aisg_mgr_wrapper.sh >/dev/null 2>&1
    killall snmpd >/dev/null 2>&1
    killall thttpd >/dev/null 2>&1
    killall alarm_mgr >/dev/null 2>&1
    killall aisg_mgr >/dev/null 2>&1
    killall housekeeper.sh >/dev/null 2>&1
    killall rc.ret1 >/dev/null 2>&1
#    killall syslogd >/dev/null 2>&1
#    killall inetd >/dev/null 2>&1
#    killall klogd >/dev/null 2>&1
#    killall crond >/dev/null 2>&1
    wdtoff >/dev/null 2>&1

    # delete backup database file.
    if [ -f /tmp/ascudb.tar ]; then
        rm -f /tmp/ascudb.tar
    fi
    if [ -f /var/ascu/ascudb.tar ]; then
        rm -f /var/ascu/ascudb.tar
    fi

    # empty all device related database files.
    if [ -f /var/ascu/Device.db ]; then
        rm -f /var/ascu/Device.db 2>&1
    fi
    if [ -f /var/ascu/Handle.db ]; then
        rm -f /var/ascu/Handle.db 2>&1
    fi
    if [ -f /var/ascu/Status.db ]; then
        rm -f /var/ascu/Status.db 2>&1
    fi
    if [ -f /var/ascu/Site.db ]; then
        rm -f /var/ascu/Site.db 2>&1
    fi

    # delete any files remaining in the untarred workspace
    rm -f /var/ascu/uploads/uploads/update/* 2>&1

    # delete install script file from root.
    if [ -f /atc300_install.sh ]; then
        rm -f /atc300_install.sh
    fi

    save
}

################################################################################
# Move aisg to min and max position.
################################################################################
delete_device_db()
{
    echo "Factory device database must be deleted before shipping."
    echo "Delete factory device database."
    echo "Enter y <ENTER> or n <ENTER>."
    read TEST_RESULT
    if [ "$TEST_RESULT" = "n" ];then
        echo "Factory device database must be deleted before shipping."
        echo "Factory device database not deleted." >> /var/log/atc300_tilt.log
    else
        #
        # "delall.sh" script will DISABLE the actuators, will not respond
        #  when actuactor is polled.  When device database is deleted using
        #  "delall.sh' script and replaced on a reinstall it will do a
        #  device scan to find and enable the device.
        #  Device scan will take long time, this will add more time to
        #   test procedure that we can not afford.
        #  Remove+Device -> MANAGER_REMOVE_DEVICE -> DISABLE_DEVICE
        #
#        /usr/bin/delall.sh >/dev/null 2>&1

        # stop the ascu and manually empty the device database files.
        kill_clean
        
        echo "Factory device database deleted." >> /var/log/atc300_tilt.log
    fi
}


#
#Start main procedure
#

if [ $# -lt 3 ]; then
	usage
else
    set_time
    get_device_count
    get_device_info
    run_tilt_test
    delete_device_db
fi
